Prophesy UI

# Prophesy - Plot

Working...
Error occured: Error value not set
(0.00, 0.00)

## Input

- Run Prism
- Select result

Prism file:
PCTL group:
PCTL property:
Run with:
Result file:

## Sampling

- Manual Sampling
- Auto Sampling

Add samples by mouse clicks
Number of iterations:
Generator type:

## Constraints

- Manual Constraints
- Auto Constraints

Add constraints by mouse clicks
Check for safe Check for bad
Constraint type:
Number of iterations:

## Settings

Threshold:
Sampler:
SMT Solver:
HeatMap: Interval bounds: ≤ ≤ ≤ ≤

## Info

### Rational Function

Not loaded